@@ -12,7 +12,6 @@ from numpy import copy        as numpy_copy
 from numpy import empty       as numpy_empty
 from numpy import expand_dims as numpy_expand_dims
 from numpy import integer     as numpy_integer
-#from numpy import isclose     as numpy_isclose
 from numpy import maximum     as numpy_maximum
 from numpy import minimum     as numpy_minimum
 from numpy import ndim        as numpy_ndim
@@ -217,7 +216,7 @@ def mask_where_too_few_values(Nmin, N, x):
 
 :Returns:
 
-    out: (`numpy.ndarray`, `numpy.ndarray`)
+    (`numpy.ndarray`, `numpy.ndarray`)
         A tuple containing *N* and *x*, both masked where *N* is
         strictly less than *Nmin*.
 
@@ -673,30 +672,26 @@ def sample_size_ffinalise(out, sub_samples=None):
 # Sum
 #---------------------------------------------------------------------
 def sum_f(a, axis=None, masked=False):
-    '''
-
-Return the sum of an array or the sum along an axis.
+    '''Return the sum of an array or the sum along an axis.
 
 ``sum_f(a, axis=axis)`` is equivalent to ``(numpy.sum(a,
 axis=axis),)``
 
 :Parameters:
 
-    array : numpy array-like
+    array: numpy array-like
         Input array
 
-    axis : int, optional
+    axis: `int`, optional
         Axis along which to operate. By default, flattened input is
         used.
 
-    kwargs : ignored
-
 :Returns:
 
-    out : tuple
+    `tuple`
         2-tuple
 
-'''
+    '''
     a = double_precision(a)
     
     N,   = sample_size_f(a, axis=axis, masked=masked)
